Learn R Programming

ambiR (version 0.1.1)

H_sal: Maximum H' as a linear function of salinity

Description

Used by DKI2(), adjusting the Shannon diversity index H' to account for decreasing species diversity with decreasing salinity.

Usage

H_sal(psal, intercept = 2.117, slope = 0.086)

Value

a numeric value H_max

Arguments

psal

numeric salinity

intercept

numeric, default 2.117

slope

numeric default 0.086

Details

AMBI_sal() and H_sal() are named, respectively, AMBI_min and H_max in the DKI documentation (Carstensen et al., 2014). They are renamed in ambiR to reflect the fact that they are functions of salinity and not minimum or maximum values from data being used.

Examples

Run this code
H_sal(20.1)

Run the code above in your browser using DataLab